@@ -19,7 +19,7 @@ class MySQLClient:
         )
         # 使用cursor()方法获取操作游标
         self.cursor = self.db.cursor()
-        self.strclass=StrClass()
+        self.strclass = StrClass()
 
     def close(self):
         self.db.close()
@@ -33,7 +33,6 @@ class MySQLClient:
         '''
         result = False
         sql = 'create table %s (%s)' % (name, (',').join(field))
-        print(sql)
         try:
             # 执行sql语句
             self.cursor.execute(sql)
@@ -81,6 +80,42 @@ class MySQLClient:
             self.close()
         return result
 
+    def insert_many(self,
+                    table: str,
+                    field: list,
+                    data: list,
+                    close: bool = True):
+        '''
+        插入数据，插入的数据内容无需做特殊安全处理，方法内均进行了html转码保存数据
+        :param table 表名
+        :param field 需要插入数据的字段列表
+        :param data 需要插入的多条数据[[],[],[]]
+        :param close 是否自动关闭数据库连接，默认True
+        :return {bool} True/False
+        '''
+        result = False
+        values = []
+        for d in data:
+            val = '(%s)' % (','.join(str(v) for v in d))
+            values.append(val)
+        sql = 'INSERT INTO %s (%s) VALUES %s' % (table, ','.join(field),
+                                                 ','.join(values))
+        try:
+            # 如果连接断开则重连
+            self.db.ping(reconnect=True)
+            # 执行sql语句
+            self.cursor.execute(sql)
+            # 提交到数据库执行
+            self.db.commit()
+            result = True
+        except:
+            # 如果发生错误则回滚
+            self.db.rollback()
+            result = False
+        if close:
+            self.close()
+        return result
+
     def fetch(self, fields: list, table: str, query: str = '', orderby: dict = None, close: bool = True):
         '''
         查询数据，查询条件数据建议使用html_escape转码保证数据查询安全
